This document is the Lubuntu Constitution, which aims to define Lubuntu as a project, its community, and its governance. If something is not explicitly defined here, please refer to the [Ubuntu Code of Conduct](https://www.ubuntu.com/community/code-of-conduct), which some parts of this document were derived from. This document is not exhaustive or complete. It is not a rulebook; it serves to distil our common understanding of a collaborative, shared environment and goals. We expect it to be followed in spirit as much as in the letter.

# Definitions

Lubuntu refers to the free software distribution project (https://lubuntu.me). This is defined as the Product in this document.

The term Council refers to the Lubuntu Council as defined in this document. Likewise, the term Members refers to the Lubuntu Members as defined in this document.

Ubuntu refers to the free software distribution project (https://www.ubuntu.com/community/governance).

The key words "MUST", "MUST NOT", "REQUIRED", "SHALL", "SHALL NOT", "SHOULD", "SHOULD NOT", "RECOMMENDED", "MAY", and "OPTIONAL" in this document are to be interpreted as described in [RFC 2119](https://tools.ietf.org/html/rfc2119).

# The Community

The Lubuntu community is defined as the people, interactions, and accounts using the Lubuntu name that are administrated by the official Lubuntu team.

Discussion on these forums should aim to be constructive, collaborative, and inclusive. If there are disagreements or misunderstandings, the parties involved should aim to resolve them in a constructive way; if this is not possible, it should be raised to the appropriate administrators, and as a last resort, the Council.

# Governance

Lubuntu is a democratic meritocracy. The individuals who contribute the most to the project as a whole, regardless of who they identify as culturally, should be given the opportunity to make the largest difference through additional responsibilities. Inversely, people who can no longer fulfill their responsibilities as a contributor should consider training and empowering other contributors to take their place; if they cannot do this, they should gracefully step down. The Council reserves the right to relieve contributors of their duties should the contributor's inability to fulfill their responsibilites actively hinders the growth of the project.

## Lubuntu Council

The Council is a board consisting of five individuals. The Council serves as the governing body of the Lubuntu project, and has the ability to do the following:

  - Mediate disputes within the community (as defined above) that cannot be resolved by themselves, or cannot be resolved peacefully.
  - Appoint team members to positions temporarily if a position being held becomes vacant, and until a new leader can be chosen.
  - Delegate administration of community groups to individuals which report directly to the Council. These delegated administrators should be the clear leaders of these groups already, to keep the spirit of democratic meritocracy.
  - Grant Lubuntu Membership to individuals within the Lubuntu project who have made significant and sustained contributions.

Quorum of the Council is defined as a majority of members casting a vote on a decision. No decision can be made on behalf of the Council without a quorum.

It is the duty of the Council to ensure the health of the community. While the Council will work to mediate problems in which a community member is acting in a way contrary to the health of the project, the Council has the authority to remove any member for violations of the Ubuntu Code of Conduct or the Lubuntu Constitution. Any removal decision made is final, and will be announced privately to Members.

The current members of the Council can be found under the [~lubuntu-council team](https://launchpad.net/~lubuntu-council) on Launchpad.

The Council members' terms expire yearly, and only Members are eligible to run for a position on the Council. Members are eligible to vote, using the [Condorcet Internet Voting Service](https://civs.cs.cornell.edu/); the results of which are put into effect after being confirmed by the expiring Council.

## Lubuntu Members

Members are official members of the Lubuntu project. In order to be a Member, an individual must demonstrate significant and sustained contributions to the Lubuntu project, and also must be confirmed by the Council.

Members are inherently [Ubuntu Members](https://wiki.ubuntu.com/Membership) as soon as they are granted Membership, and since the benefits of which are also granted, the same high expectations upheld for Ubuntu Members must also be upheld for Members.

In order for a Member to renew their membership, they must have contributed to the project in a notable way between the last time their membership status was updated or renewed and the expiry date. Membership in the team is valid for one year from the renewal date.

A current list of Members can be found under the [~lubuntu-members team](https://launchpad.net/~lubuntu-members) on Launchpad.

## Role of the Ubuntu Community Council

The Ubuntu Community Council is the governing board of the Ubuntu project, and as Lubuntu is a sub-project of Ubuntu, the Ubuntu Community Council is a direct parent board of the Council. As a board they have the ability to override any decision made by the Council, and the Council will consult them for major decisions.

## Team Lead

The Lubuntu Team Lead is a Council member which serves as a representative for the Council when executive action is required and the Council cannot reach a quorum. This team member is appointed directly by the Council. If the Team Lead takes any action, they must inform the Council immediately, and the Council has the right to overrule any decision made by the Team Lead. Intentional failure to report any decision to the Council within that time will result in re-evaluation by the Council of the Team Lead's ability to serve.

## Delegated Positions

The following are the current administrative positions delegated by the Council. They have the ability to appoint assistants to their position which take their place in the case that they are no longer fit to fulfull their duties, either temporarily or permanently. The Council must be informed when delegates choose to appoint someone as an assistant. Both the delegates and the assistant delegates should be the clear leaders of these groups already, to keep the spirit of democratic meritocracy.

It is important that none of the delegated administrators have access to tools or documentation that the Council does not have. To reduce bus factor in the case that an individual has to step away suddenly, the Council must have the same access that the delegates do.

### Lubuntu Release Manager

The Lubuntu Release Manager is the individual responsible for all release management for the Product. They make the final decision as to what packages are in the Product (although this is subject to platform expectations set by the Ubuntu Technical Board), the release goals for the Product, and whether or not the Product is in a releasable state. They serve as the point of contact for Product releases, and have the ability to establish release-related rules for Product-specific packages.

### Lubuntu Quality Assurance Manager

The Lubuntu Quality Assurance Manager, or the Lubuntu QA Manager, is the individual responsible for testing the Product. They conduct exploratory testing, establish quality assurance and bug triage policies for the Product, and assist the Release Manager in finding testers for the Product prior to a release. They serve as the point of contact for bugs in Lubuntu, and work with the Lubuntu Release Manager to determine if the Product is in a releasable state.

### Lubuntu Documentation Manager

The Lubuntu Documentation Manager is the individual responsible for all of Lubuntu's documentation. They make the final decisions for all of the content which goes into the Lubuntu Manual and any other documentation which is officially released on behalf of the project. They aim to gather relevant information from the community and transform it into something that is easy to read.

### Lubuntu Design Manager

The Lubuntu Design Manager is the individual responsible for design and user experience decisions in the Product. They aim to take feedback from the community and other team members regarding how to improve the design of the Product and what the best experience for the end user is.

### Lubuntu Localization Manager

The Lubuntu Localization Manager is the individual responsible for ensuring Lubuntu is translated into as many languages as possible, and that the translations are high-quality as well as accurate. This individual may wish to establish interest groups for specific languages if there is a significant amount of people who speak that language and are interested in Lubuntu.

### Digital Communications Managers

There is no one person who manages the social media and digital communications for Lubuntu, but interested parties who can prove prior experience with a social media or digital communications platform can be added as administrators at the Council's discretion.

# Modifications to this document

Modifications to this document must only be made following unanimous consensus among the Council. Before large changes are merged, feedback from active Members and the Ubuntu Community Council as well as the Council should be incorporated.

The canonical location of this document is available on [our Phabricator instance in Markdown format](https://phab.lubuntu.me/source/constitution/browse/master/Constitution.md). For accessibility purposes, a copy is also available on [GitHub](https://github.com/lubuntu-team/constitution/blob/master/Constitution.md), but this should be considered "best-effort" and the Phabricator copy should be used.

This document is licensed under the [Creative Commons Attribution-Share Alike 3.0 license](http://creativecommons.org/licenses/by-sa/3.0/). You may re-use it for your own project, and modify it as you wish, just please allow others to use your modifications and give credit to the Lubuntu project.
